
#ifndef ACCOUNTS_EXPORT_H
#define ACCOUNTS_EXPORT_H

#ifdef ACCOUNTS_STATIC_DEFINE
#  define ACCOUNTS_EXPORT
#  define ACCOUNTS_NO_EXPORT
#else
#  ifndef ACCOUNTS_EXPORT
#    ifdef MauiKitAccounts4_EXPORTS
        /* We are building this library */
#      define ACCOUNTS_EXPORT __attribute__((visibility("default")))
#    else
        /* We are using this library */
#      define ACCOUNTS_EXPORT __attribute__((visibility("default")))
#    endif
#  endif

#  ifndef ACCOUNTS_NO_EXPORT
#    define ACCOUNTS_NO_EXPORT __attribute__((visibility("hidden")))
#  endif
#endif

#ifndef ACCOUNTS_DEPRECATED
#  define ACCOUNTS_DEPRECATED __attribute__ ((__deprecated__))
#endif

#ifndef ACCOUNTS_DEPRECATED_EXPORT
#  define ACCOUNTS_DEPRECATED_EXPORT ACCOUNTS_EXPORT ACCOUNTS_DEPRECATED
#endif

#ifndef ACCOUNTS_DEPRECATED_NO_EXPORT
#  define ACCOUNTS_DEPRECATED_NO_EXPORT ACCOUNTS_NO_EXPORT ACCOUNTS_DEPRECATED
#endif

/* NOLINTNEXTLINE(readability-avoid-unconditional-preprocessor-if) */
#if 0 /* DEFINE_NO_DEPRECATED */
#  ifndef ACCOUNTS_NO_DEPRECATED
#    define ACCOUNTS_NO_DEPRECATED
#  endif
#endif

#endif /* ACCOUNTS_EXPORT_H */
